Helper functions for testing Krill.
Constants
Functions
Starts a krill pubd for testing on its own port, and its
own temp dir for storage.
Starts a Krill server with a testbed and an RRDP interval, so that we can test that
RRDP delta delays work properly.
Starts krill server for testing using the given configuration. Creates a random base directory in the ‘work’ folder,
adjusts the config to use it and returns it. Be sure to clean it up when the test is done.
Starts krill server for testing using the default test configuration, and optionally with testbed mode enabled.
Creates a random base directory in the ‘work’ folder, and returns it. Be sure to clean it up when the test is done.
Starts a krill pubd for testing on its own port, and its
own temp dir for storage.
This method sets up a random subdirectory and returns it. It is
assumed that the caller will clean this directory themselves.
This method sets up a test directory with a random name (a number)
under ‘work’, relative to where cargo is running. It then runs the
test provided in the closure, and finally it cleans up the test
directory.